#
# spec file for package python-django-tastypie
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-django-tastypie
Version:        0.14.3
Release:        bp154.1.24
Summary:        A webservice API framework layer for Django
License:        BSD-3-Clause
URL:            https://github.com/django-tastypie/django-tastypie
Source:         https://github.com/django-tastypie/django-tastypie/archive/v%{version}.tar.gz
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module biplist}
BuildRequires:  %{python_module defusedxml}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module python-dateutil >= 2.1}
BuildRequires:  %{python_module python-mimeparse >= 0.1.4}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11
Requires:       python-python-dateutil >= 2.1
Requires:       python-python-mimeparse >= 0.1.4
Recommends:     python-PyYAML
Recommends:     python-biplist
Recommends:     python-defusedxml
Recommends:     python-lxml
BuildArch:      noarch
%python_subpackages

%description
Tastypie is a webservice API framework for Django. It provides a
customizable abstraction for creating REST-style interfaces.

%prep
%setup -q -n django-tastypie-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# The tests are doing what is specified in tox.ini
%{python_expand export PYTHONPATH=./tests/
$python -m django test -p '*' core.tests --settings=settings_core
$python -m django test basic.tests --settings=settings_basic
$python -m django test related_resource.tests --settings=settings_related
$python -m django test alphanumeric.tests --settings=settings_alphanumeric
$python -m django test authorization.tests --settings=settings_authorization
$python -m django test content_gfk.tests --settings=settings_content_gfk
$python -m django test customuser.tests --settings=settings_customuser
$python -m django test namespaced.tests --settings=settings_namespaced
$python -m django test slashless.tests --settings=settings_slashless
$python -m django test validation.tests --settings=settings_validation
}

%files %{python_files}
%license LICENSE
%doc AUTHORS *.rst docs/*.rst docs/release_notes/ docs/code/
%{python_sitelib}/*

%changelog
* Thu Jan  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.14.3:
  * no upstream changelog
* Sun Feb 24 2019 John Vandenberg <jayvdb@gmail.com>
- Add AUTHORS, other *.rst files, and docs/ to %%doc
- Update to v0.14.2
  * Added support for Django 2.1; minor bugs and regressions fixed.
    + Incorporates django-tastypie-django21.patch
  * Drops support for Django 1.8 LTS.
* Thu Aug 16 2018 jengelh@inai.de
- Replace useless description.
* Tue Aug 14 2018 tchvatal@suse.com
- Version update to 0.14.1:
  * Fixes to support latest django
- Run tests
- Add patch for django 2.1:
  * django-tastypie-django21.patch
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Wed Apr 22 2015 mcihar@suse.cz
- Update to version 0.12.1:
  * Drastic reworking of the test suite. (SHA: 95f57f7)
  * Fixed Travis to run Python 3.4 tests. (SHA: 7af528c)
  * Fixed a bug where URLs would be incorrectly handled if the ``api_name`` &
    ``resource_name`` were the same. (SHA: fd55aa3)
  * Fixed a test requirement for PyYAML. (SHA: b4f6531)
  * Added support for Django 1.7. (SHA: 7881bb6)
  * Documentation updates
* Mon Jul  7 2014 mcihar@suse.cz
- Update to verson 0.11.1
  + Fixes XSS
  + Fixes security issue in URL parsing
  + Many other bugfixes
* Sat Sep 28 2013 p.drouand@gmail.com
- Update to version 0.10
  + No changelog available
- Replace python-distribute with python-setuptools BuildRequires
* Mon Jul 15 2013 mcihar@suse.cz
- Update to version 0.9.15:
  * No changelog available
* Thu Feb 14 2013 p.drouand@gmail.com
- Update to version 0.9.12:
  * No changelog available
* Wed Mar 21 2012 saschpe@gmx.de
- Initial version
